#ifndef DEFINITIONS_H
#define DEFINITIONS_H
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Image definitions
#define IMAGE_FILE_NAME "/home/user/MyDocs/.images/image.jpg"
#define IMAGE_FILE_TYPE "JPG"

//-----------------------------------------------------------------------------
#endif // DEFINITIONS_H
